@@ -2,7 +2,7 @@ import random
 
 from . import parsers
 from .dictionary import questions, default_ans, greet, ty_replies
-from .utils import get_data_from_wiki
+from . import utils
 
 class Friday:
 
@@ -26,16 +26,18 @@ class Friday:
 
     @classmethod
     def think(self, cmd: str) -> str:
-        if "thank" in cmd:
-            return ty_replies[random.randint(0, len(ty_replies) - 1)] + ", Sir"
         if cmd.startswith("say "):
             return cmd.replace("say ", "")
+        if "thank" in cmd:
+            return ty_replies[random.randint(0, len(ty_replies) - 1)] + ", Sir"
         if all([i in cmd for i in ["what", "time"]]):
             return parsers.parse_time()
         if all([i in cmd for i in ["what", "battery"]]):
             return parsers.parse_battery_data()
+        if all([i in cmd for i in ["what", "weather"]]):
+            return utils.get_weather_data()
         if any([cmd.startswith(i) for i in questions]):
-            return get_data_from_wiki(cmd)
+            return utils.get_wiki_data(cmd)
         if any([i in cmd for i in greet]):
             return greet[random.randint(0, len(greet) - 1)] + " !"
         return default_ans[random.randint(0, len(default_ans) - 1)]
