@@ -1,4 +1,4 @@
 from friday import Friday
 
-Friday.listen("wat's the battery percenatge ?")
+Friday.listen("what's the weather ?")
 print(Friday._cmd, Friday.reply())
